@@ -2,8 +2,8 @@
 
 ;; Author: Colin McLear <mclear@fastmail.com>
 ;; Maintainer: Colin McLear
-;; Package-Version: 20260206.225
-;; Package-Revision: 3b801a7cc698
+;; Package-Version: 20260222.1958
+;; Package-Revision: 06fe5ad149bc
 ;; Package-Requires: ((emacs "27.1") (project "0.8.1"))
 ;; Keywords: convenience, frames
 ;; Homepage: https://github.com/mclear-tools/tabspaces
@@ -57,6 +57,7 @@
 
 (declare-function magit-init "magit-status")
 (declare-function magit-status-setup-buffer "magit-status")
+(declare-function ibuffer-current-buffer "ibuffer" (&optional must-be-live))
 
 ;;;; Variables
 
@@ -559,6 +560,13 @@ tab."
      (t
       (switch-to-buffer buffer norecord force-same-window)))))
 
+;;;###autoload
+(defun tabspaces-ibuffer-switch-buffer-and-tab ()
+  "In ibuffer, switch to the tab containing the buffer at point."
+  (interactive)
+  (let ((buf (ibuffer-current-buffer t)))
+    (tabspaces-switch-buffer-and-tab (buffer-name buf))))
+
 (defun tabspaces-clear-buffers (&optional frame)
   "Clear the tabspace's buffer list, except for the current buffer.
 If FRAME is nil, use the current frame."
@@ -717,7 +725,7 @@ With universal argument PREFIX, always create a new tab for the project."
          (original-tab-name (or (cdr (assoc project tabspaces-project-tab-map))
                                 (tabspaces-generate-descriptive-tab-name project existing-tab-names)))
          (tab-name original-tab-name)
-         (session (concat project "." (file-name-nondirectory (directory-file-name project)) "-tabspaces-session.el"))
+         (session (tabspaces--get-project-session-file-for-restore project))
          (project-directory project)  ; Use the full path as the project directory
          (project-exists (member (list project) project--list))
          (create-new-tab (or prefix (not (member tab-name existing-tab-names)))))
